[tor-commits] [torsocks/master] test: Change IPs with the new ones TPO just setup

dgoulet at torproject.org dgoulet at torproject.org
Mon Jun 13 21:14:03 UTC 2016


commit 3e875fd3f4ea8a0c723b9c416e24ea22a03ea80d
Author: David Goulet <dgoulet at ev0ke.net>
Date:   Mon Jun 13 14:52:24 2016 -0400

    test: Change IPs with the new ones TPO just setup
    
    Signed-off-by: David Goulet <dgoulet at ev0ke.net>
---
 tests/test_dns.c        | 4 ++--
 tests/test_fd_passing.c | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/tests/test_dns.c b/tests/test_dns.c
index 7d592ac..03ce976 100644
--- a/tests/test_dns.c
+++ b/tests/test_dns.c
@@ -34,8 +34,8 @@ struct test_host {
 
 /* Tor check hostname/ip. */
 static const struct test_host tor_check = {
-	.name = "sergii.torproject.org",
-	.ip = "38.229.72.22",
+	.name = "perdulce.torproject.org",
+	.ip = "138.201.14.203",
 };
 
 /* moria1 directory authority. */
diff --git a/tests/test_fd_passing.c b/tests/test_fd_passing.c
index 1803126..e5eb10f 100644
--- a/tests/test_fd_passing.c
+++ b/tests/test_fd_passing.c
@@ -448,11 +448,11 @@ static void test_inet_socket(void)
 	void *status;
 	pthread_t th[2];
 	struct sockaddr_in addr;
-	const char *ip = "93.95.227.222";
+	const char *ip = "138.201.14.197";
 
 	/*
 	 * First of all, we are going to try to create an inet socket to a public
 	 * known IP being www.torproject.org --> 93.95.227.222.
 	 */
 	inet_sock = socket(AF_INET, SOCK_STREAM, 0);
 	if (inet_sock < 0) {
@@ -448,11 +448,11 @@ static void test_inet_socket(void)
 	/*
 	 * First of all, we are going to try to create an inet socket to a public
-	 * known IP being www.torproject.org --> 93.95.227.222.
+	 * known IP being www.torproject.org --> 138.201.14.197.
 	 */
 	inet_sock = socket(AF_INET, SOCK_STREAM, 0);





More information about the tor-commits mailing list